//
//  ViewController.swift
//  iCloudFiles
//
//  Created by Keith Welch on 9/25/15.
//  Copyright © 2015 Keith Welch. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

    @IBOutlet weak var txtText: UITextView!
    
    var docFile:String!
    var docUrl:NSURL!
    var doc:CloudDoc!
    var cloudDocsUrl:NSURL!
    var ubiquityURL:NSURL!
    var metadataQuery:NSMetadataQuery!

    override func viewDidLoad() {
        super.viewDidLoad()
        
        // set up local directory
        let paths:NSArray = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        let documentsDirectory = paths[0] as! NSString
        docFile = documentsDirectory.stringByAppendingPathComponent("UIDocument.txt")
        docUrl = NSURL(fileURLWithPath: docFile)
        doc = CloudDoc(fileURL:docUrl)
        doc.text = ""
        
        let filemgr = NSFileManager.defaultManager()
        
        do {
            // get iCloud url
            try filemgr.removeItemAtURL(docUrl)
        }
        catch let error as NSError {
            NSLog(error.description)
        }
        
        do {
            // get iCloud url and add a Documents directory
            let cloudUrl:NSURL? = filemgr.URLForUbiquityContainerIdentifier(nil)
            if (cloudUrl != nil) {
                cloudDocsUrl = cloudUrl!.URLByAppendingPathComponent("Documents")
                
                // check for its existence first
                if (!filemgr.fileExistsAtPath(cloudDocsUrl.path!)) {
                    try filemgr.createDirectoryAtURL(cloudDocsUrl, withIntermediateDirectories:true, attributes:nil)
                }
                
                // now add the file name to the url
                ubiquityURL = cloudDocsUrl.URLByAppendingPathComponent("UIDocument.txt")
            }
        }
        catch let error as NSError {
            NSLog(error.description)
        }
        
    }

    @IBAction func btnReadTouched(sender: AnyObject) {
        // Search for document in iCloud storage
        metadataQuery = NSMetadataQuery()
        metadataQuery.predicate = NSPredicate(format: "%K like %@", NSMetadataItemFSNameKey, "UIDocument.txt")
        metadataQuery.searchScopes = [NSMetadataQueryUbiquitousDocumentsScope]
        
        NSNotificationCenter.defaultCenter().addObserver(self, selector: "metadataQueryDidFinishGathering:", name: NSMetadataQueryDidFinishGatheringNotification, object: metadataQuery)
        metadataQuery.startQuery()

    }
    
    func metadataQueryDidFinishGathering(notification: NSNotification) {

        metadataQuery.disableUpdates()
        
        NSNotificationCenter.defaultCenter().removeObserver(self, name: NSMetadataQueryDidFinishGatheringNotification, object: metadataQuery)
        
        metadataQuery.stopQuery()

        let results = NSArray(array: metadataQuery.results)
        
        if (results.count == 1) {
            // File exists
            ubiquityURL = results[0].valueForAttribute(NSMetadataItemURLKey) as! NSURL
            
            // create the doc object from url
            doc = CloudDoc(fileURL:ubiquityURL)
            doc.openWithCompletionHandler({ (success) -> Void in
                if (success){
                    self.txtText.text = self.doc.text;
                }

            })
        }
        else {
            // File does not exist in cloud.
            // create an empty one
            doc = CloudDoc(fileURL:ubiquityURL)
            
            doc.saveToURL(ubiquityURL, forSaveOperation: UIDocumentSaveOperation.ForCreating, completionHandler: {(success) -> Void in
                if (success){
                    NSLog("Created cloud doc");
                }
            })
        }
    }
    
    @IBAction func btnWriteTouched(sender: AnyObject) {
        doc.text = txtText.text
        doc.saveToURL(ubiquityURL, forSaveOperation:UIDocumentSaveOperation.ForOverwriting, completionHandler:{(success) -> Void in
            if (success) {
                NSLog("doc saved")
            }
        })
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }


}

